@@ -1,7 +1,7 @@
 from werkzeug.exceptions import abort
 
-from app import DB
-from models.user import User, UserSchema
+from ..app import DB
+from ..models.user import User, UserSchema
 
 
 def get_users_list():
