@@ -1,6 +1,6 @@
 import os
-from app import DB, DB_FILE_NAME
-from models.agreement import AgreementDummy
+from .app import DB, DB_FILE_NAME
+from .models.agreement import AgreementDummy
 
 # Delete database file if it exists currently
 if os.path.exists(DB_FILE_NAME):
